Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(405)

Unified Diff: net/http/http_stream_factory_impl_job.h

Issue 2894303002: Change HttpStreamFactoryImpl::Job to take a AlternativeServiceInfo
Patch Set: Change QuicStreamFactory::CreateSession() to take a QUIC version. Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | net/http/http_stream_factory_impl_job.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/http_stream_factory_impl_job.h
diff --git a/net/http/http_stream_factory_impl_job.h b/net/http/http_stream_factory_impl_job.h
index 11361536f1881623bf027d8ad81f0b60f2d26b10..7d48475e25a18b5fee1206b630ab07532d59ad07 100644
--- a/net/http/http_stream_factory_impl_job.h
+++ b/net/http/http_stream_factory_impl_job.h
@@ -179,7 +179,7 @@ class HttpStreamFactoryImpl::Job {
const SSLConfig& proxy_ssl_config,
HostPortPair destination,
GURL origin_url,
- AlternativeService alternative_service,
+ const AlternativeServiceInfo& alternative_service_info,
const ProxyServer& alternative_proxy_server,
bool enable_ip_based_pooling,
NetLog* net_log);
@@ -232,7 +232,7 @@ class HttpStreamFactoryImpl::Job {
JobType job_type() const { return job_type_; }
const AlternativeService alternative_service() const {
- return alternative_service_;
+ return alternative_service_info_.alternative_service;
}
const ProxyServer alternative_proxy_server() const {
@@ -416,8 +416,8 @@ class HttpStreamFactoryImpl::Job {
// original request when host mapping rules are set-up.
const GURL origin_url_;
- // AlternativeService for this Job if this is an alternative Job.
- const AlternativeService alternative_service_;
+ // AlternativeServiceInfo for this Job if this is an alternative Job.
+ const AlternativeServiceInfo alternative_service_info_;
// Alternative proxy server that should be used by |this| to fetch the
// request.
@@ -518,7 +518,7 @@ class HttpStreamFactoryImpl::JobFactory {
const SSLConfig& proxy_ssl_config,
HostPortPair destination,
GURL origin_url,
- AlternativeService alternative_service,
+ const AlternativeServiceInfo& alternative_service_info,
bool enable_ip_based_pooling,
NetLog* net_log);
« no previous file with comments | « no previous file | net/http/http_stream_factory_impl_job.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698